import axios from "axios";
import type { Error } from "./entities/error";

interface APIFetchData {
	method?: string;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
	data?: any;
	token?: string;
	headers?: Record<string, string>;
	version?: number;
}

export async function apiFetch<T>(
	path: string,
	data: APIFetchData | undefined = undefined,
) {
	try {
		const resp = await axios<T>({
			method: data?.method || "GET",
			url: `/api/v${data?.version || 1}${path}`,
			data: data?.data,
		});

		return resp.data;
		// eslint-disable-next-line @typescript-eslint/no-explicit-any
	} catch (err: any) {
		if (err.response) {
			throw err as Error;
		}

		throw err;
	}
}
